@@ -1,5 +1,5 @@
 lag2.plot <-
-function(series1,series2,max.lag=0,corr=TRUE,smooth=TRUE,col=gray(.1)){ 
+function(series1,series2,max.lag=0,corr=TRUE,smooth=TRUE,col=gray(.1), ...){ 
    #
    as.ts = stats::as.ts
    par = graphics::par
@@ -20,7 +20,7 @@ function(series1,series2,max.lag=0,corr=TRUE,smooth=TRUE,col=gray(.1)){
    old.par <- par(no.readonly = TRUE)
    par(mfrow=c(prow,pcol),  mar=c(2.5, 2.5, 1, 1), mgp=c(1.6,.6,0), cex.main=1, font.main=1)
    for(h in 0:max.lag){                   
-   plot(stats::lag(series1,-h), series2, xy.labels=FALSE, main=paste(name1,h,")",sep=""), ylab=name2, xlab="", col=col, panel.first=Grid()) 
+   plot(stats::lag(series1,-h), series2, xy.labels=FALSE, main=paste(name1,h,")",sep=""), ylab=name2, xlab="", col=col, panel.first=Grid(), ...) 
     if (smooth==TRUE) 
     lines(stats::lowess(ts.intersect(stats::lag(series1,-h),series2)[,1],
                  ts.intersect(stats::lag(series1,-h),series2)[,2]), col="red")
